Polygon

Struct Polygon 

pub struct Polygon<D, F>
where D: DualNum<F>, F: DualNumFloat,
{ /* private fields */ }
A polygon represented by a list of vertices.

Implementations

Source

impl<D, F> Polygon<D, F>
where D: DualNum<F> + ComplexField<RealField = D>, F: DualNumFloat,

pub fn new(vertices: Vec<Point2<D>>) -> Self

Creates a new Polygon<F>. Returns a reference to the vector of distances between consecutive vertices.

Returns

A slice of distances of type F.

pub fn new_centered_rectangle(width: D, height: D) -> Self

pub fn distance(&self) -> &[D]

Returns a reference to the vector of cumulative distances.